### API Reference
Read The Docs: [Link Here](https://aminopy.readthedocs.io/en/latest/)

### What Is This?
This unofficial repository of Amino.py and Is A Python API For Communicating With Amino Servers Whilst Pretending That You're An App User. This Is Mostly Accomplished By Spoofing Device Configuration Headers. It Is Also For Objectifying And Organizing Amino Response Data, So That Actually Doing Anything Is Easier.

#### How do I use this?
You'll Need Python 3 To Use This Library, I Recommend Using Python 3.6 Or Earlier.
To Install It Just Open The Command Line And Type This Command `python -m pip install Amino.ed`